@@ -73,6 +73,7 @@ __all__ = (
     "PutPlaybackConfigurationResponseTypeDef",
     "RequestOutputItemTypeDef",
     "ResponseOutputItemTypeDef",
+    "ScheduleAdBreakTypeDef",
     "ScheduleConfigurationTypeDef",
     "ScheduleEntryTypeDef",
     "SecretsManagerAccessTokenConfigurationTypeDef",
@@ -562,6 +563,17 @@ class ResponseOutputItemTypeDef(
     pass
 
 
+ScheduleAdBreakTypeDef = TypedDict(
+    "ScheduleAdBreakTypeDef",
+    {
+        "ApproximateDurationSeconds": int,
+        "ApproximateStartTime": datetime,
+        "SourceLocationName": str,
+        "VodSourceName": str,
+    },
+    total=False,
+)
+
 ScheduleConfigurationTypeDef = TypedDict(
     "ScheduleConfigurationTypeDef",
     {
@@ -584,6 +596,7 @@ _OptionalScheduleEntryTypeDef = TypedDict(
     {
         "ApproximateDurationSeconds": int,
         "ApproximateStartTime": datetime,
+        "ScheduleAdBreaks": List["ScheduleAdBreakTypeDef"],
     },
     total=False,
 )
